SoftPointwiseHingeLoss
======================

.. currentmodule:: pykeen.losses

.. autoclass:: SoftPointwiseHingeLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SoftPointwiseHingeLoss.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
